import * as _nuxt_schema from '@nuxt/schema';

interface SanityConfiguration {
    useCdn?: boolean;
    projectId: string;
    dataset?: string;
    apiVersion: string;
    withCredentials?: boolean;
    token?: string;
}

interface SanityModuleOptions extends Partial<SanityConfiguration> {
    /**
     * Use a micro-client that only supports making queries.
     * @default false
     */
    minimal?: boolean;
    /**
     * Register a global SanityImage component to generate correct Sanity image URLs
     * @default true
     */
    imageHelper?: boolean;
    /**
     * Register a global SanityContent component to serialize Sanity Portable Text
     * @default true
     */
    contentHelper?: boolean;
    /**
     * Don't disable `useCdn` when preview mode is on
     * https://nuxtjs.org/docs/2.x/features/live-preview/
     *
     * @default false
     */
    disableSmartCdn?: boolean;
    /**
     * Configuration for any additional clients
     */
    additionalClients?: Record<string, Partial<SanityConfiguration>>;
}
declare type ModuleOptions = SanityModuleOptions;
declare const _default: _nuxt_schema.NuxtModule<SanityModuleOptions>;

export { ModuleOptions, SanityModuleOptions, _default as default };
